@@ -19,7 +19,7 @@ use Perinci::Sub::Util qw(err);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-11-02'; # DATE
 our $DIST = 'Perinci-Sub-Gen-AccessTable'; # DIST
-our $VERSION = '0.589'; # VERSION
+our $VERSION = '0.590'; # VERSION
 
 our @EXPORT_OK = qw(gen_read_table_func);
 
@@ -277,6 +277,16 @@ _
             'x.name.is_plural' => 1,
             'x.name.singular' => 'query',
         },
+        description => N__(<<'_',
+
+This will search all searchable fields with one or more specified queries. Each
+query can be in the form of `-FOO` (dash prefix notation) to require that the
+fields do not contain specified string, or `/FOO/` to use regular expression.
+All queries must match if the `query_boolean` option is set to `and`; only one
+query should match if the `query_boolean` option is set to `or`.
+
+_
+                       )
     ) if $opts->{enable_filtering} && $opts->{enable_search};
     _add_arg(
         func_meta   => $func_meta,
@@ -288,6 +298,13 @@ _
         cat_name    => 'filtering',
         cat_text    => N__('filtering'),
         summary     => N__("Whether records must match all search queries ('and') or just one ('or')"),
+        description => N__(<<'_',
+
+If set to `and`, all queries must match; if set to `or`, only one query should
+match. See the `queries` option for more details on searching.
+
+_
+                       )
     ) if $opts->{enable_filtering} && $opts->{enable_search};
 
     # add filter arguments for each table field
@@ -694,6 +711,7 @@ sub __parse_query {
                 word => $opts->{word_search},
                 bool => $args->{query_boolean} // $opts->{default_query_boolean} // 'and',
                 ci   => $opts->{case_insensitive_search},
+                re   => 1,
             },
             @qq);
     }
@@ -1639,7 +1657,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.589 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2022-11-02.
+This document describes version 0.590 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2022-11-02.
 
 =head1 SYNOPSIS
 
